@@ -14,15 +14,15 @@ from typing import (
     cast,
 )
 
+from lilya.apps import Lilya
+from lilya.middleware import DefineMiddleware  # noqa
+from lilya.types import Lifespan, Receive, Scope, Send
 from openapi_schemas_pydantic.v3_1_0 import Contact, License, SecurityScheme
 from openapi_schemas_pydantic.v3_1_0.open_api import OpenAPI
 from pydantic import AnyUrl, ValidationError
-from starlette.applications import Starlette
-from starlette.middleware import Middleware as StarletteMiddleware  # noqa
-from starlette.types import Lifespan, Receive, Scope, Send
 from typing_extensions import Annotated, Doc
 
-from esmerald.conf import settings as esmerald_settings
+from esmerald.conf import reload_settings, settings as esmerald_settings
 from esmerald.conf.global_settings import EsmeraldAPISettings
 from esmerald.config import CORSConfig, CSRFConfig, SessionConfig
 from esmerald.config.openapi import OpenAPIConfig
@@ -35,6 +35,7 @@ from esmerald.exception_handlers import (
 )
 from esmerald.exceptions import ImproperlyConfigured, ValidationErrorException
 from esmerald.interceptors.types import Interceptor
+from esmerald.middleware.app_settings import ApplicationSettingsMiddleware
 from esmerald.middleware.asyncexitstack import AsyncExitStackMiddleware
 from esmerald.middleware.cors import CORSMiddleware
 from esmerald.middleware.csrf import CSRFMiddleware
@@ -65,12 +66,13 @@ from esmerald.utils.helpers import is_class_and_subclass
 
 if TYPE_CHECKING:  # pragma: no cover
     from esmerald.conf import EsmeraldLazySettings
+    from esmerald.datastructures import Secret
     from esmerald.types import SettingsType, TemplateConfig
 
 AppType = TypeVar("AppType", bound="Esmerald")
 
 
-class Esmerald(Starlette):
+class Esmerald(Lilya):
     """
     `Esmerald` application object. The main entry-point for any application/API
     with Esmerald.
@@ -141,7 +143,7 @@ class Esmerald(Starlette):
     def __init__(
         self: AppType,
         *,
-        settings_config: Annotated[
+        settings_module: Annotated[
             Optional["SettingsType"],
             Doc(
                 """
@@ -171,7 +173,7 @@ class Esmerald(Starlette):
                 Boolean indicating if the application should return the debug tracebacks on
                 server errors, in other words, if you want to have debug errors being displayed.
 
-                Read more about this in the official [Starlette documentation](https://www.starlette.io/applications/#instantiating-the-application).
+                Read more about this in the official [Lilya documentation](https://www.lilya.dev/applications/#applications).
 
                 !!! Tip
                     Do not use this in production.
@@ -455,7 +457,7 @@ class Esmerald(Starlette):
             ),
         ] = None,
         secret_key: Annotated[
-            Optional[str],
+            Union[Optional[str], Optional["Secret"]],
             Doc(
                 """
                 A unique string value used for the cryptography. This value is also
@@ -571,7 +573,7 @@ class Esmerald(Starlette):
 
                 ```python
                 from loguru import logger
-                from starlette.types import Receive, Scope, Send
+                from lilya.types import Receive, Scope, Send
 
                 from esmerald import Esmerald
                 from esmerald import EsmeraldInterceptor
@@ -1021,7 +1023,7 @@ class Esmerald(Starlette):
                     routes=[
                         Gateway(handler=homepage)
                         Include("/nested", routes=[
-                            Gateway(handler="/another")
+                            Gateway(handler=another)
                         ])
                     ]
                 )
@@ -1057,7 +1059,7 @@ class Esmerald(Starlette):
             Optional[Sequence["Middleware"]],
             Doc(
                 """
-                A global sequence of Starlette middlewares or `esmerald.middlewares` that are
+                A global sequence of Lilya middlewares or `esmerald.middlewares` that are
                 used by the application.
 
                 Read more about the [Middleware](https://esmerald.dev/middleware/middleware/).
@@ -1071,8 +1073,8 @@ class Esmerald(Starlette):
                 app = Esmerald(
                     routes=[...],
                     middleware=[
-                        StarletteMiddleware(TrustedHostMiddleware, allowed_hosts=["example.com", "*.example.com"]),
-                        StarletteMiddleware(HTTPSRedirectMiddleware),
+                        DefineMiddleware(TrustedHostMiddleware, allowed_hosts=["example.com", "*.example.com"]),
+                        DefineMiddleware(HTTPSRedirectMiddleware),
                     ],
                 )
                 ```
@@ -1464,19 +1466,18 @@ class Esmerald(Starlette):
             ),
         ] = None,
     ) -> None:
-        self.settings_config = None
-
-        if settings_config:
-            if not isinstance(settings_config, EsmeraldAPISettings) and not is_class_and_subclass(
-                settings_config, EsmeraldAPISettings
+        self.settings_module = None
+        if settings_module is not None:
+            if not isinstance(settings_module, EsmeraldAPISettings) and not is_class_and_subclass(
+                settings_module, EsmeraldAPISettings
             ):
                 raise ImproperlyConfigured(
-                    "settings_config must be a subclass of EsmeraldSettings"
+                    "settings_module must be a subclass of EsmeraldSettings"
                 )
-            elif isinstance(settings_config, EsmeraldAPISettings):
-                self.settings_config = settings_config  # type: ignore
-            elif is_class_and_subclass(settings_config, EsmeraldAPISettings):
-                self.settings_config = settings_config()
+            elif isinstance(settings_module, EsmeraldAPISettings):
+                self.settings_module = settings_module  # type: ignore
+            elif is_class_and_subclass(settings_module, EsmeraldAPISettings):
+                self.settings_module = settings_module()  # type: ignore
 
         assert lifespan is None or (
             on_startup is None and on_shutdown is None
@@ -1569,7 +1570,7 @@ class Esmerald(Starlette):
                 This can be defined as the application state and not request state
                 which means that it does not change each request.
 
-                Learn more in the [Starlette documentation](https://www.starlette.io/applications/#storing-state-on-the-app-instance).
+                Learn more in the [Lilya documentation](https://www.lilya.dev/applications/#storing-state-on-the-app-instance).
                 """
             ),
         ] = State()
@@ -1623,12 +1624,16 @@ class Esmerald(Starlette):
         """
         if not is_boolean:
             if not value:
-                return self.get_settings_value(self.settings_config, esmerald_settings, name)
+                return self.get_settings_value(
+                    cast("EsmeraldAPISettings", self.settings_module), esmerald_settings, name
+                )
             return value
 
         if value is not None:
             return value
-        return self.get_settings_value(self.settings_config, esmerald_settings, name)
+        return self.get_settings_value(
+            cast("EsmeraldAPISettings", self.settings_module), esmerald_settings, name
+        )
 
     def create_webhooks_signature_model(self, webhooks: Sequence[gateways.WebhookGateway]) -> None:
         """
@@ -1719,6 +1724,7 @@ class Esmerald(Starlette):
             set_value(self.openapi_version, "openapi_version")
             set_value(self.summary, "summary")
             set_value(self.description, "description")
+            set_value(self.contact, "contact")
             set_value(self.tags, "tags")
             set_value(self.servers, "servers")
             set_value(self.terms_of_service, "terms_of_service")
@@ -1887,7 +1893,7 @@ class Esmerald(Starlette):
             Optional[List["Middleware"]],
             Doc(
                 """
-                A list of middleware to run for every request. The middlewares of an Include will be checked from top-down or [Starlette Middleware](https://www.starlette.io/middleware/) as they are both converted internally. Read more about [Python Protocols](https://peps.python.org/pep-0544/).
+                A list of middleware to run for every request. The middlewares of an Include will be checked from top-down or [Lilya Middleware](https://www.lilya.dev/middleware/) as they are both converted internally. Read more about [Python Protocols](https://peps.python.org/pep-0544/).
                 """
             ),
         ] = None,
@@ -1895,7 +1901,7 @@ class Esmerald(Starlette):
             Optional[str],
             Doc(
                 """
-                The name for the Gateway. The name can be reversed by `url_path_for()`.
+                The name for the Gateway. The name can be reversed by `path_for()`.
                 """
             ),
         ] = None,
@@ -1936,10 +1942,10 @@ class Esmerald(Starlette):
         **Example**
 
         ```python
-        from esmerald import get
+        from esmerald import Esmerald, get
 
         @get(status_code=status_code)
-        async def hello(self) -> str:
+        async def hello() -> str:
             return "Hello, World!"
 
         app = Esmerald()
@@ -1994,7 +2000,7 @@ class Esmerald(Starlette):
             Optional[str],
             Doc(
                 """
-                The name for the Gateway. The name can be reversed by `url_path_for()`.
+                The name for the WebSocketGateway. The name can be reversed by `path_for()`.
                 """
             ),
         ] = None,
@@ -2034,7 +2040,7 @@ class Esmerald(Starlette):
             Optional[List["Middleware"]],
             Doc(
                 """
-                A list of middleware to run for every request. The middlewares of an Include will be checked from top-down or [Starlette Middleware](https://www.starlette.io/middleware/) as they are both converted internally. Read more about [Python Protocols](https://peps.python.org/pep-0544/).
+                A list of middleware to run for every request. The middlewares of an Include will be checked from top-down or [Lilya Middleware](https://www.lilya.dev/middleware/) as they are both converted internally. Read more about [Python Protocols](https://peps.python.org/pep-0544/).
                 """
             ),
         ] = None,
@@ -2048,7 +2054,7 @@ class Esmerald(Starlette):
         **Example**
 
         ```python
-        from esmerald import websocket
+        from esmerald import Esmerald, websocket
 
         @websocket()
         async def websocket_route(socket: WebSocket) -> None:
@@ -2141,7 +2147,7 @@ class Esmerald(Starlette):
         **Example**
 
         ```python
-        from esmerald import get, Include, ChildEsmerald
+        from esmerald import get, Include, ChildEsmerald, Esmerald
 
         @get(status_code=status_code)
         async def hello(self) -> str:
@@ -2214,7 +2220,7 @@ class Esmerald(Starlette):
                         dependencies=route.dependencies,
                         exception_handlers=route.exception_handlers,
                         name=route.name,
-                        middleware=route.middleware,
+                        middleware=cast("List[Middleware]", route.middleware),
                         interceptors=route.interceptors,
                         permissions=route.permissions,
                         routes=cast("Sequence[Union[APIGateHandler, Include]]", route.routes),
@@ -2287,7 +2293,7 @@ class Esmerald(Starlette):
             exception_handlers = {}
 
         if isinstance(route, Include):
-            exception_handlers.update(route.exception_handlers)  # type: ignore
+            exception_handlers.update(route.exception_handlers)
             app = getattr(route, "app", None)
             if app and isinstance(app, (Esmerald, ChildEsmerald)):
                 return exception_handlers
@@ -2298,31 +2304,13 @@ class Esmerald(Starlette):
                 )
 
         if isinstance(route, (gateways.Gateway, gateways.WebSocketGateway)):
-            exception_handlers.update(route.exception_handlers)  # type: ignore
+            exception_handlers.update(route.exception_handlers)
             if route.handler.exception_handlers:
-                exception_handlers.update(route.handler.exception_handlers)  # type: ignore
+                exception_handlers.update(route.handler.exception_handlers)
 
         return exception_handlers
 
-    def build_routes_middleware(
-        self, route: "RouteParent", middlewares: Optional[List["Middleware"]] = None
-    ) -> List["Middleware"]:
-        """
-        Builds the middleware stack from the top to the bottom of the routes.
-
-        The includes are an exception as they are treated as an independent ASGI
-        application and therefore handles their own middlewares independently.
-        """
-        if not middlewares:
-            middlewares = []
-
-        if isinstance(route, Include):
-            app = getattr(route, "app", None)
-            if app and isinstance(app, (Esmerald, ChildEsmerald)):
-                return middlewares
-        return middlewares
-
-    def build_user_middleware_stack(self) -> List["StarletteMiddleware"]:
+    def build_user_middleware_stack(self) -> List["DefineMiddleware"]:
         """
         Configures all the passed settings
         and wraps inside an exception handler.
@@ -2333,40 +2321,36 @@ class Esmerald(Starlette):
         It evaluates the middleware passed into the routes from bottom up
         """
         user_middleware = []
-        handlers_middleware: List["Middleware"] = []
 
         if self.allowed_hosts:
             user_middleware.append(
-                StarletteMiddleware(TrustedHostMiddleware, allowed_hosts=self.allowed_hosts)
+                DefineMiddleware(TrustedHostMiddleware, allowed_hosts=self.allowed_hosts)
             )
         if self.cors_config:
             user_middleware.append(
-                StarletteMiddleware(CORSMiddleware, **self.cors_config.model_dump())
+                DefineMiddleware(CORSMiddleware, **self.cors_config.model_dump())
             )
         if self.csrf_config:
-            user_middleware.append(StarletteMiddleware(CSRFMiddleware, config=self.csrf_config))
+            user_middleware.append(
+                DefineMiddleware(CSRFMiddleware, **self.csrf_config.model_dump())
+            )
 
         if self.session_config:
             user_middleware.append(
-                StarletteMiddleware(SessionMiddleware, **self.session_config.model_dump())
+                DefineMiddleware(SessionMiddleware, **self.session_config.model_dump())
             )
 
-        handlers_middleware += self.router.middleware
-        for route in self.routes or []:
-            handlers_middleware.extend(self.build_routes_middleware(route))
-
-        self._middleware += handlers_middleware
         for middleware in self._middleware or []:
-            if isinstance(middleware, StarletteMiddleware):
+            if isinstance(middleware, DefineMiddleware):
                 user_middleware.append(middleware)
             else:
-                user_middleware.append(StarletteMiddleware(middleware))
+                user_middleware.append(DefineMiddleware(middleware))
         return user_middleware
 
     def build_middleware_stack(self) -> "ASGIApp":
         """
         Esmerald uses the [esmerald.protocols.MiddlewareProtocol] (interfaces) and therefore we
-        wrap the StarletteMiddleware in a slighly different manner.
+        wrap the DefineMiddleware in a slighly different manner.
 
         Overriding the default build_middleware_stack will allow to control the initial
         middlewares that are loaded by Esmerald. All of these values can be updated.
@@ -2392,7 +2376,7 @@ class Esmerald(Starlette):
 
         middleware = (
             [
-                StarletteMiddleware(
+                DefineMiddleware(
                     EsmeraldAPIExceptionMiddleware,
                     exception_handlers=exception_handlers,
                     error_handler=error_handler,
@@ -2401,18 +2385,19 @@ class Esmerald(Starlette):
             ]
             + self.user_middleware
             + [
-                StarletteMiddleware(
+                DefineMiddleware(ApplicationSettingsMiddleware),
+                DefineMiddleware(
                     ExceptionMiddleware,
                     handlers=exception_handlers,
                     debug=debug,
                 ),
-                StarletteMiddleware(AsyncExitStackMiddleware, config=self.async_exit_config),
+                DefineMiddleware(AsyncExitStackMiddleware, config=self.async_exit_config),
             ]
         )
 
         app: "ASGIApp" = self.router
-        for cls, options in reversed(middleware):
-            app = cls(app=app, **options)
+        for cls, args, kwargs in reversed(middleware):
+            app = cls(app=app, *args, **kwargs)  # noqa
         return app
 
     def build_pluggable_stack(self) -> Optional["Esmerald"]:
@@ -2495,7 +2480,7 @@ class Esmerald(Starlette):
         app.settings
         ```
         """
-        general_settings = self.settings_config if self.settings_config else esmerald_settings
+        general_settings = self.settings_module if self.settings_module else esmerald_settings
         return cast("Type[EsmeraldAPISettings]", general_settings)
 
     @cached_property
@@ -2507,15 +2492,34 @@ class Esmerald(Starlette):
         """
         return esmerald_settings
 
+    async def build_include_scope(self, scope: Scope) -> Scope:
+        """
+        Builds the scope for a specific mounted application.
+        """
+        if "route_root_path" in scope:
+            if "root_include_path" not in scope:
+                scope["root_include_path"] = scope["route_root_path"]
+        return scope
+
+    async def globalise_settings(self) -> None:
+        """
+        Making sure the global settings remain as is
+        after the request is done.
+        """
+        settings = reload_settings()
+        esmerald_settings.configure(settings())
+
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
-        scope["app"] = self
         if scope["type"] == "lifespan":
             await self.router.lifespan(scope, receive, send)
             return
+
         if self.root_path:
             scope["root_path"] = self.root_path
+
         scope["state"] = {}
         await super().__call__(scope, receive, send)
+        await self.globalise_settings()
 
     def route(
         self,
