@@ -1,16 +1,23 @@
 from functools import cached_property
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
 
+from lilya.types import Lifespan
 from openapi_schemas_pydantic.v3_1_0 import Contact, License, SecurityScheme
 from pydantic import AnyUrl
 from pydantic_settings import BaseSettings, SettingsConfigDict
-from starlette.types import Lifespan
 from typing_extensions import Annotated, Doc
 
 from esmerald import __version__
 from esmerald.conf.enums import EnvironmentType
-from esmerald.config import CORSConfig, CSRFConfig, OpenAPIConfig, SessionConfig, StaticFilesConfig
+from esmerald.config import (
+    CORSConfig,
+    CSRFConfig,
+    OpenAPIConfig,
+    SessionConfig,
+    StaticFilesConfig,
+)
 from esmerald.config.asyncexit import AsyncExitConfig
+from esmerald.datastructures import Secret
 from esmerald.interceptors.types import Interceptor
 from esmerald.permissions.types import Permission
 from esmerald.pluggables import Pluggable
@@ -44,7 +51,7 @@ class EsmeraldAPISettings(BaseSettings):
     When no values are provided upon an instantiation of an `Esmerald` object, these
     settings are used as the defaults.
 
-    The settings can be done via `ESMERALD_SETTINGS_MODULE` or `settings_config` parameter
+    The settings can be done via `ESMERALD_SETTINGS_MODULE` or `settings_module` parameter
     in the Esmerald instantiation.
 
     Learn more about [settings](https://esmerald.dev/application/settings/).
@@ -76,7 +83,7 @@ class EsmeraldAPISettings(BaseSettings):
             Boolean indicating if the application should return the debug tracebacks on
             server errors, in other words, if you want to have debug errors being displayed.
 
-            Read more about this in the official [Starlette documentation](https://www.starlette.io/applications/#instantiating-the-application).
+            Read more about this in the official [Lilya documentation](https://www.lilya.dev/applications/#instantiating-the-application).
 
             !!! Tip
                 Do not use this in production as `True`.
@@ -225,7 +232,7 @@ class EsmeraldAPISettings(BaseSettings):
         ),
     ] = [{"url": "/"}]
     secret_key: Annotated[
-        str,
+        Union[str, Secret],
         Doc(
             """
             A unique string value used for the cryptography. This value is also
@@ -542,7 +549,7 @@ class EsmeraldAPISettings(BaseSettings):
             This is used as the default if no [OpenAPIConfig](https://esmerald.dev/configurations/openapi/config/) is provided.
             """
         ),
-    ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.1.3/swagger-ui-bundle.min.js"
+    ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.9.0/swagger-ui-bundle.min.js"
     swagger_css_url: Annotated[
         str,
         Doc(
@@ -553,7 +560,7 @@ class EsmeraldAPISettings(BaseSettings):
             This is used as the default if no [OpenAPIConfig](https://esmerald.dev/configurations/openapi/config/) is provided.
             """
         ),
-    ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.1.3/swagger-ui.min.css"
+    ] = "https://cdn.jsdelivr.net/npm/swagger-ui-dist@5.9.0/swagger-ui.min.css"
     swagger_favicon_url: Annotated[
         str,
         Doc(
@@ -727,7 +734,7 @@ class EsmeraldAPISettings(BaseSettings):
                     Gateway(handler=homepage)
                     Include("/nested",
                         routes=[
-                            Gateway(handler="/another")
+                            Gateway(handler=another)
                         ]
                     )
                 ]
@@ -819,7 +826,7 @@ class EsmeraldAPISettings(BaseSettings):
 
         class AppSettings(EsmeraldAPISettings):
             @property
-            def template_config(self) -> "TemplateConfig":
+            def template_config(self) -> TemplateConfig:
                 TemplateConfig(directory='templates', engine=MakoTemplateEngine)
         ```
         """
@@ -882,7 +889,7 @@ class EsmeraldAPISettings(BaseSettings):
         """
         An instance of [SessionConfig](https://esmerald.dev/configurations/session/).
 
-        This configuration is passed to the [SessionMiddleware]https://esmerald.dev/middleware/middleware/#sessionmiddleware) and enables the middleware.
+        This configuration is passed to the [SessionMiddleware](https://esmerald.dev/middleware/middleware/#sessionmiddleware) and enables the middleware.
 
         Default:
             None
@@ -970,7 +977,7 @@ class EsmeraldAPISettings(BaseSettings):
     @property
     def middleware(self) -> Sequence[Middleware]:
         """
-        A global sequence of Starlette middlewares or `esmerald.middlewares` that are
+        A global sequence of Lilya middlewares or `esmerald.middlewares` that are
         used by the application.
 
         Read more about the [Middleware](https://esmerald.dev/middleware/middleware/).
@@ -983,10 +990,10 @@ class EsmeraldAPISettings(BaseSettings):
         ```python
         from esmerald import EsmeraldAPISettings
         from esmerald.middleware import HTTPSRedirectMiddleware, TrustedHostMiddleware
-        from starlette.middleware import Middleware as StarletteMiddleware
+        from lilya.middleware import Middleware as StarletteMiddleware
 
 
-        Class AppSettings(EsmeraldAPISettings):
+        class AppSettings(EsmeraldAPISettings):
 
             @property
             def middleware(self) -> List[Middleware]:
@@ -1136,7 +1143,7 @@ class EsmeraldAPISettings(BaseSettings):
 
         ```python
         from loguru import logger
-        from starlette.types import Receive, Scope, Send
+        from lilya.types import Receive, Scope, Send
 
         from esmerald import Esmerald, EsmeraldInterceptor, EsmeraldAPISettings
 
@@ -1417,3 +1424,13 @@ class EsmeraldAPISettings(BaseSettings):
         ```
         """
         return {}
+
+    def __hash__(self) -> int:
+        values: Dict[str, Any] = {}
+        for key, value in self.__dict__.items():
+            values[key] = None
+            if isinstance(value, (list, set)):
+                values[key] = tuple(value)
+            else:
+                values[key] = value
+        return hash((type(self),) + tuple(values))
