@@ -345,7 +345,7 @@ class OpenAPIConfig(BaseModel):
             webhooks=self.webhooks,
         )
         app.openapi_schema = openapi_schema
-        return openapi_schema
+        return app.openapi_schema
 
     def enable(self, app: Any) -> None:
         """Enables the OpenAPI documentation"""
@@ -353,9 +353,10 @@ class OpenAPIConfig(BaseModel):
             urls = {server.get("url") for server in self.servers}
             server_urls = set(urls)
 
-            @get(path=self.openapi_url)
+            @get(path=self.openapi_url)  # type: ignore
             async def _openapi(request: Request) -> JSONResponse:
                 root_path = request.scope.get("root_path", "").rstrip("/")
+
                 if root_path not in server_urls:
                     if root_path and self.root_path_in_servers:
                         self.servers.insert(0, {"url": root_path})
@@ -363,13 +364,18 @@ class OpenAPIConfig(BaseModel):
                 return JSONResponse(self.openapi(app))
 
             app.add_route(
-                path="/", handler=_openapi, include_in_schema=False, activate_openapi=False
+                path="/",
+                handler=_openapi,
+                include_in_schema=False,
+                activate_openapi=False,
             )
 
         if self.openapi_url and self.docs_url:
 
-            @get(path=self.docs_url)
-            async def swagger_ui_html(request: Request) -> HTMLResponse:  # pragma: no cover
+            @get(path=self.docs_url)  # type: ignore
+            async def swagger_ui_html(
+                request: Request,
+            ) -> HTMLResponse:  # pragma: no cover
                 root_path = request.scope.get("root_path", "").rstrip("/")
                 openapi_url = root_path + self.openapi_url
                 oauth2_redirect_url = self.swagger_ui_oauth2_redirect_url
@@ -395,8 +401,10 @@ class OpenAPIConfig(BaseModel):
 
         if self.swagger_ui_oauth2_redirect_url:
 
-            @get(self.swagger_ui_oauth2_redirect_url)
-            async def swagger_ui_redirect(request: Request) -> HTMLResponse:  # pragma: no cover
+            @get(self.swagger_ui_oauth2_redirect_url)  # type: ignore
+            async def swagger_ui_redirect(
+                request: Request,
+            ) -> HTMLResponse:  # pragma: no cover
                 return get_swagger_ui_oauth2_redirect_html()
 
             app.add_route(
@@ -408,7 +416,7 @@ class OpenAPIConfig(BaseModel):
 
         if self.openapi_url and self.redoc_url:
 
-            @get(self.redoc_url)
+            @get(self.redoc_url)  # type: ignore
             async def redoc_html(request: Request) -> HTMLResponse:  # pragma: no cover
                 root_path = request.scope.get("root_path", "").rstrip("/")
                 openapi_url = root_path + self.openapi_url
@@ -421,13 +429,18 @@ class OpenAPIConfig(BaseModel):
                 )
 
             app.add_route(
-                path="/", handler=redoc_html, include_in_schema=False, activate_openapi=False
+                path="/",
+                handler=redoc_html,
+                include_in_schema=False,
+                activate_openapi=False,
             )
 
         if self.openapi_url and self.stoplight_url:
 
-            @get(self.stoplight_url)
-            async def stoplight_html(request: Request) -> HTMLResponse:  # pragma: no cover
+            @get(self.stoplight_url)  # type: ignore
+            async def stoplight_html(
+                request: Request,
+            ) -> HTMLResponse:  # pragma: no cover
                 root_path = request.scope.get("root_path", "").rstrip("/")
                 openapi_url = root_path + self.openapi_url
                 return get_stoplight_html(
@@ -439,7 +452,10 @@ class OpenAPIConfig(BaseModel):
                 )
 
             app.add_route(
-                path="/", handler=stoplight_html, include_in_schema=False, activate_openapi=False
+                path="/",
+                handler=stoplight_html,
+                include_in_schema=False,
+                activate_openapi=False,
             )
 
         app.router.activate()
