@@ -1,4 +1,5 @@
-UNUSABLE_PASSWORD_PREFIX = "!"  # This will never be a valid encoded hash
+# This will never be a valid encoded hash
+UNUSABLE_PASSWORD_PREFIX = "!"
 UNUSABLE_PASSWORD_SUFFIX_LENGTH = (
     40  # number of random chars to add after UNUSABLE_PASSWORD_PREFIX
 )
