@@ -4,12 +4,15 @@ import json
 import warnings
 from typing import Any, Dict, List, Optional, Sequence, Set, Tuple, Union, cast
 
+from lilya._internal._path import clean_path
+from lilya.middleware import DefineMiddleware
+from lilya.routing import BasePath
+from lilya.status import HTTP_422_UNPROCESSABLE_ENTITY
+from lilya.transformers import TRANSFORMER_TYPES
+from orjson import loads
 from pydantic import AnyUrl
 from pydantic.fields import FieldInfo
 from pydantic.json_schema import GenerateJsonSchema, JsonSchemaValue
-from starlette.middleware import Middleware
-from starlette.routing import BaseRoute
-from starlette.status import HTTP_422_UNPROCESSABLE_ENTITY
 from typing_extensions import Literal
 
 from esmerald.enums import MediaType
@@ -36,18 +39,21 @@ from esmerald.openapi.utils import (
 from esmerald.params import Param
 from esmerald.routing import gateways, router
 from esmerald.typing import Undefined
-from esmerald.utils.constants import DATA
+from esmerald.utils.constants import DATA, PAYLOAD
 from esmerald.utils.helpers import is_class_and_subclass
-from esmerald.utils.url import clean_path
 
 
 def get_flat_params(route: Union[router.HTTPHandler, Any]) -> List[Any]:
     """Gets all the neded params of the request and route"""
     path_params = [param.field_info for param in route.transformer.get_path_params()]
     cookie_params = [param.field_info for param in route.transformer.get_cookie_params()]
-    query_params = [param.field_info for param in route.transformer.get_query_params()]
     header_params = [param.field_info for param in route.transformer.get_header_params()]
 
+    query_params = []
+    for param in route.transformer.get_query_params():
+        if param.field_info.annotation.__class__.__name__ in TRANSFORMER_TYPES.keys():
+            query_params.append(param.field_info)
+
     return path_params + query_params + cookie_params + header_params
 
 
@@ -75,7 +81,7 @@ def get_openapi_security_schemes(schemes: Any) -> Tuple[dict, list]:
 
 
 def get_fields_from_routes(
-    routes: Sequence[BaseRoute], request_fields: Optional[List[FieldInfo]] = None
+    routes: Sequence[BasePath], request_fields: Optional[List[FieldInfo]] = None
 ) -> List[FieldInfo]:
     """Extracts the fields from the given routes of Esmerald"""
     body_fields: List[FieldInfo] = []
@@ -95,7 +101,10 @@ def get_fields_from_routes(
             handler = cast(router.HTTPHandler, route.handler)
 
             # Get the data_field
-            if DATA in handler.signature_model.model_fields:
+            if (
+                DATA in handler.signature_model.model_fields
+                or PAYLOAD in handler.signature_model.model_fields
+            ):
                 data_field = handler.data_field
                 body_fields.append(data_field)
 
@@ -115,9 +124,7 @@ def get_openapi_operation(
     *, route: Union[router.HTTPHandler, Any], operation_ids: Set[str]
 ) -> Dict[str, Any]:  # pragma: no cover
     operation = Operation()
-
-    if route.tags:
-        operation.tags = route.get_handler_tags()
+    operation.tags = route.get_handler_tags()
 
     if route.summary:
         operation.summary = route.summary
@@ -128,11 +135,12 @@ def get_openapi_operation(
         operation.description = route.description
 
     operation_id = route.operation_id
+
     if operation_id in operation_ids:
         message = (
-            f"Duplicate Operation ID {operation_id} for function " + f"{route.endpoint.__name__}"
+            f"Duplicate Operation ID {operation_id} for function " + f"{route.handler.__name__}"
         )
-        file_name = getattr(route.endpoint, "__globals__", {}).get("__file__")
+        file_name = getattr(route.handler, "__globals__", {}).get("__file__")
         if file_name:
             message += f" at {file_name}"
         warnings.warn(message, stacklevel=1)
@@ -176,9 +184,9 @@ def get_openapi_operation_parameters(
         if field_info.examples is not None:
             parameter.example = json.dumps(field_info.examples)
         if field_info.deprecated:
-            parameter.deprecated = field_info.deprecated
+            parameter.deprecated = field_info.deprecated  # type: ignore
 
-        parameters.append(parameter.model_dump(by_alias=True))
+        parameters.append(parameter.model_dump(by_alias=True, exclude_none=True))
     return parameters
 
 
@@ -287,7 +295,9 @@ def get_openapi_path(
 
         # Media type
         if route_response_media_type and is_status_code_allowed(handler.status_code):
-            response_schema = {"type": "string"}
+            response_schema = (
+                {"type": "string"} if handler.status_code not in handler.responses else {}
+            )
 
             operation.setdefault("responses", {}).setdefault(status_code, {}).setdefault(
                 "content", {}
@@ -333,7 +343,6 @@ def get_openapi_path(
                     or status_text
                     or "Additional Response"
                 )
-
                 dict_update(openapi_response, model_schema)
                 openapi_response["description"] = description
 
@@ -396,7 +405,7 @@ def is_middleware_app(route: router.Include) -> bool:
     """
     from esmerald import MiddlewareProtocol
 
-    return bool(isinstance(route.app, (Middleware, MiddlewareProtocol)))
+    return bool(isinstance(route.app, (DefineMiddleware, MiddlewareProtocol)))
 
 
 def get_openapi(
@@ -407,13 +416,13 @@ def get_openapi(
     openapi_version: str = "3.1.0",
     summary: Optional[str] = None,
     description: Optional[str] = None,
-    routes: Sequence[BaseRoute],
+    routes: Sequence[BasePath],
     tags: Optional[List[str]] = None,
     servers: Optional[List[Dict[str, Union[str, Any]]]] = None,
     terms_of_service: Optional[Union[str, AnyUrl]] = None,
     contact: Optional[Contact] = None,
     license: Optional[License] = None,
-    webhooks: Optional[Sequence[BaseRoute]] = None,
+    webhooks: Optional[Sequence[BasePath]] = None,
 ) -> Dict[str, Any]:  # pragma: no cover
     """
     Builds the whole OpenAPI route structure and object
@@ -454,7 +463,7 @@ def get_openapi(
     # Iterate through the routes
     def iterate_routes(
         app: Any,
-        routes: Sequence[BaseRoute],
+        routes: Sequence[BasePath],
         definitions: Any = None,
         components: Any = None,
         prefix: Optional[str] = "",
@@ -543,5 +552,5 @@ def get_openapi(
         output["tags"] = tags
 
     openapi = OpenAPI(**output)
-    model_dump = openapi.model_dump(by_alias=True, exclude_none=True)
-    return model_dump
+    model_dump = openapi.model_dump_json(by_alias=True, exclude_none=True)
+    return cast(Dict[str, Any], loads(model_dump))
