@@ -21,17 +21,12 @@ class AsyncDAOProtocol(Protocol):  # pragma: no cover
     data access to a database.
     """
 
-    async def get(self, obj_id: Any) -> Any:
-        ...
+    async def get(self, obj_id: Any, **kwargs: Any) -> Any: ...
 
-    async def get_all(self, **kwargs: Any) -> List[Any]:
-        ...
+    async def get_all(self, **kwargs: Any) -> List[Any]: ...
 
-    async def update(self, obj_id: Any, **kwargs: Any) -> Any:
-        ...
+    async def update(self, obj_id: Any, **kwargs: Any) -> Any: ...
 
-    async def delete(self, obj_id: Any) -> Any:
-        ...
+    async def delete(self, obj_id: Any, **kwargs: Any) -> Any: ...
 
-    async def create(self, **kwargs: Any) -> Any:
-        ...
+    async def create(self, **kwargs: Any) -> Any: ...
