@@ -20,12 +20,11 @@ from typing import (
 )
 from uuid import UUID
 
-from starlette.convertors import CONVERTOR_TYPES
-from starlette.requests import HTTPConnection
-from starlette.responses import Response as StarletteResponse
-from starlette.routing import Mount as Mount  # noqa
-from starlette.routing import compile_path
-from starlette.types import Receive, Scope, Send
+from lilya._internal._connection import Connection
+from lilya.responses import Response as LilyaResponse
+from lilya.routing import compile_path
+from lilya.transformers import TRANSFORMER_TYPES
+from lilya.types import Receive, Scope, Send
 from typing_extensions import TypedDict
 
 from esmerald.backgound import BackgroundTask, BackgroundTasks
@@ -37,10 +36,14 @@ from esmerald.permissions.utils import continue_or_raise_permission_exception
 from esmerald.requests import Request
 from esmerald.responses import JSONResponse, Response
 from esmerald.routing.apis.base import View
-from esmerald.transformers.model import TransformerModel
+from esmerald.transformers.model import (
+    TransformerModel,
+    create_signature as transfomer_create_signature,
+)
 from esmerald.transformers.signature import SignatureFactory
 from esmerald.transformers.utils import get_signature
 from esmerald.typing import Void, VoidType
+from esmerald.utils.constants import DATA, PAYLOAD
 from esmerald.utils.helpers import is_async_callable, is_class_and_subclass
 from esmerald.utils.sync import AsyncCallable
 
@@ -75,7 +78,7 @@ param_type_map = {
     "path": Path,
 }
 
-CONV2TYPE = {conv: typ for typ, conv in CONVERTOR_TYPES.items()}
+CONV2TYPE = {conv: typ for typ, conv in TRANSFORMER_TYPES.items()}
 
 
 T = TypeVar("T", bound="BaseHandlerMixin")
@@ -90,10 +93,10 @@ class PathParameterSchema(TypedDict):
 class OpenAPIDefinitionMixin:  # pragma: no cover
     def parse_path(self, path: str) -> List[Union[str, PathParameterSchema]]:
         """
-        Using the Starlette CONVERTORS and the application registered convertors,
+        Using the Lilya TRANSFORMERS and the application registered convertors,
         transforms the path into a PathParameterSchema used for the OpenAPI definition.
         """
-        _, path, variables = compile_path(path)
+        _, path, variables, _ = compile_path(path)
 
         parsed_components: List[Union[str, PathParameterSchema]] = []
 
@@ -141,7 +144,7 @@ class BaseSignature:
         dependencies = self.get_dependencies()
         signature_model = get_signature(self)
 
-        return TransformerModel.create_signature(
+        return transfomer_create_signature(
             signature_model=signature_model,
             dependencies=dependencies,
             path_parameters=self.path_parameters,
@@ -164,7 +167,7 @@ class BaseResponseHandler:
 
         async def response_content(
             data: ResponseContainer, app: Type["Esmerald"], **kwargs: Dict[str, Any]
-        ) -> StarletteResponse:
+        ) -> LilyaResponse:
             _headers = {**self.get_headers(headers), **data.headers}
             _cookies = self.get_cookies(data.cookies, cookies)
             response: Response = data.to_response(
@@ -186,7 +189,7 @@ class BaseResponseHandler:
         status_code: Optional[int] = None,
         media_type: Optional[str] = MediaType.TEXT,
     ) -> "AsyncAnyCallable":
-        async def response_content(data: Response, **kwargs: Dict[str, Any]) -> StarletteResponse:
+        async def response_content(data: Response, **kwargs: Dict[str, Any]) -> LilyaResponse:
             _cookies = self.get_cookies(data.cookies, cookies)
             _headers = {
                 **self.get_headers(headers),
@@ -217,7 +220,7 @@ class BaseResponseHandler:
     ) -> "AsyncAnyCallable":
         """Creates a handler function for Esmerald JSON responses"""
 
-        async def response_content(data: Response, **kwargs: Dict[str, Any]) -> StarletteResponse:
+        async def response_content(data: Response, **kwargs: Dict[str, Any]) -> LilyaResponse:
             _cookies = self.get_cookies(cookies, [])
             _headers = {
                 **self.get_headers(headers),
@@ -236,16 +239,14 @@ class BaseResponseHandler:
 
         return response_content
 
-    def starlette_response_handler(
+    def lilya_response_handler(
         self,
         cookies: "ResponseCookies",
         headers: Optional["ResponseHeaders"] = None,
     ) -> "AsyncAnyCallable":
-        """Creates an handler for Starlette Responses."""
+        """Creates an handler for Lilya Responses."""
 
-        async def response_content(
-            data: StarletteResponse, **kwargs: Dict[str, Any]
-        ) -> StarletteResponse:
+        async def response_content(data: LilyaResponse, **kwargs: Dict[str, Any]) -> LilyaResponse:
             _cookies = self.get_cookies(cookies, [])
             _headers = {
                 **self.get_headers(headers),
@@ -270,7 +271,8 @@ class BaseResponseHandler:
         response_class: Any,
         status_code: int,
     ) -> "AsyncAnyCallable":
-        async def response_content(data: Any, **kwargs: Dict[str, Any]) -> StarletteResponse:
+        async def response_content(data: Any, **kwargs: Dict[str, Any]) -> LilyaResponse:
+
             data = await self.get_response_data(data=data)
             _cookies = self.get_cookies(cookies, [])
             if isinstance(data, JSONResponse):
@@ -298,17 +300,26 @@ class BaseResponseHandler:
         request: Request,
         route: "HTTPHandler",
         parameter_model: "TransformerModel",
-    ) -> "StarletteResponse":
-        response: Optional["StarletteResponse"] = None
-        if not response:
-            response = await self.call_handler_function(
-                scope=scope,
-                request=request,
-                route=route,
-                parameter_model=parameter_model,
-            )
+    ) -> "LilyaResponse":
+        """
+        Get response for the given request using the specified route and parameter model.
 
-        return response
+        Args:
+            scope (Scope): The scope of the request.
+            request (Request): The incoming request.
+            route (HTTPHandler): The route handler for the request.
+            parameter_model (TransformerModel): The parameter model for handling request parameters.
+
+        Returns:
+            LilyaResponse: The response generated for the request.
+        """
+        response = await self.call_handler_function(
+            scope=scope,
+            request=request,
+            route=route,
+            parameter_model=parameter_model,
+        )
+        return cast("LilyaResponse", response)
 
     async def call_handler_function(
         self,
@@ -317,6 +328,18 @@ class BaseResponseHandler:
         route: "HTTPHandler",
         parameter_model: "TransformerModel",
     ) -> Any:
+        """
+        Call the handler function for the given request and return the response data.
+
+        Args:
+            scope (Scope): The scope of the request.
+            request (Request): The incoming request.
+            route (HTTPHandler): The route handler for the request.
+            parameter_model (TransformerModel): The parameter model for handling request parameters.
+
+        Returns:
+            Any: The response data generated by the handler function.
+        """
         response_data = await self._get_response_data(
             route=route,
             parameter_model=parameter_model,
@@ -333,27 +356,39 @@ class BaseResponseHandler:
         route: "HTTPHandler", parameter_model: "TransformerModel", request: Request
     ) -> Any:
         """
-        Determines what kwargs are required for the given handler and assignes to the specific
-        object dictionary.
+        Determine required kwargs for the given handler, assign to the object dictionary, and get the response data.
 
-        It supports more one object payload to be sent.
+        Args:
+            route (HTTPHandler): The route handler for the request.
+            parameter_model (TransformerModel): The parameter model for handling request parameters.
+            request (Request): The incoming request.
+
+        Returns:
+            Any: The response data generated by processing the request.
         """
         signature_model = get_signature(route)
+        is_data_or_payload: str = None
 
         if parameter_model.has_kwargs:
-            kwargs = parameter_model.to_kwargs(connection=request)
-            request_data = kwargs.get("data")
+            kwargs = parameter_model.to_kwargs(connection=request, handler=route)
+
+            is_data_or_payload = DATA if kwargs.get(DATA) else PAYLOAD
+            request_data = kwargs.get(DATA) or kwargs.get(PAYLOAD)
+
             if request_data:
-                kwargs["data"] = await request_data
+                kwargs[is_data_or_payload] = await request_data
+
             for dependency in parameter_model.dependencies:
                 kwargs[dependency.key] = await parameter_model.get_dependencies(
                     dependency=dependency, connection=request, **kwargs
                 )
+
             parsed_kwargs = signature_model.parse_values_for_connection(
                 connection=request, **kwargs
             )
         else:
             parsed_kwargs = {}
+
         if isinstance(route.parent, View):
             fn = partial(
                 cast("AnyCallable", route.fn),
@@ -367,7 +402,7 @@ class BaseResponseHandler:
             return await fn()
         return fn()
 
-    def get_response_handler(self) -> Callable[[Any], Awaitable[StarletteResponse]]:
+    def get_response_handler(self) -> Callable[[Any], Awaitable[LilyaResponse]]:
         """
         Checks and validates the type of return response and maps to the corresponding
         handler with the given parameters.
@@ -381,7 +416,7 @@ class BaseResponseHandler:
             headers = self.get_response_headers()
             cookies = self.get_response_cookies()
 
-            if is_class_and_subclass(self.signature.return_annotation, ResponseContainer):
+            if is_class_and_subclass(self.handler_signature.return_annotation, ResponseContainer):
                 handler = self.response_container_handler(
                     cookies=cookies,
                     media_type=self.media_type,
@@ -389,21 +424,21 @@ class BaseResponseHandler:
                     headers=headers,
                 )
             elif is_class_and_subclass(
-                self.signature.return_annotation,
+                self.handler_signature.return_annotation,
                 JSONResponse,
             ):
                 handler = self.json_response_handler(
                     status_code=self.status_code, cookies=cookies, headers=headers
                 )
-            elif is_class_and_subclass(self.signature.return_annotation, Response):
+            elif is_class_and_subclass(self.handler_signature.return_annotation, Response):
                 handler = self.response_handler(
                     cookies=cookies,
                     status_code=self.status_code,
                     media_type=self.media_type,
                     headers=headers,
                 )
-            elif is_class_and_subclass(self.signature.return_annotation, StarletteResponse):
-                handler = self.starlette_response_handler(
+            elif is_class_and_subclass(self.handler_signature.return_annotation, LilyaResponse):
+                handler = self.lilya_response_handler(
                     cookies=cookies,
                     headers=headers,
                 )
@@ -417,8 +452,9 @@ class BaseResponseHandler:
                     status_code=self.status_code,
                 )
             self._response_handler = handler
+
         return cast(
-            "Callable[[Any], Awaitable[StarletteResponse]]",
+            "Callable[[Any], Awaitable[LilyaResponse]]",
             self._response_handler,
         )
 
@@ -429,7 +465,7 @@ class BaseHandlerMixin(BaseSignature, BaseResponseHandler, OpenAPIDefinitionMixi
     """
 
     @property
-    def signature(self) -> Signature:
+    def handler_signature(self) -> Signature:
         """The Signature of 'self.fn'."""
         return Signature.from_callable(cast("AnyCallable", self.fn))
 
@@ -571,7 +607,7 @@ class BaseHandlerMixin(BaseSignature, BaseResponseHandler, OpenAPIDefinitionMixi
             data = await data
         return data
 
-    async def allow_connection(self, connection: "HTTPConnection") -> None:  # pragma: no cover
+    async def allow_connection(self, connection: "Connection") -> None:  # pragma: no cover
         """
         Validates the connection.
 
@@ -607,7 +643,8 @@ class BaseHandlerMixin(BaseSignature, BaseResponseHandler, OpenAPIDefinitionMixi
         for tag in tags:
             if tag not in tags_clean:
                 tags_clean.append(tag)
-        return tags_clean
+
+        return tags_clean if tags_clean else None
 
 
 class BaseInterceptorMixin(BaseHandlerMixin):  # pragma: no cover
