@@ -13,9 +13,8 @@ from typing import (
     get_args,
 )
 
-from starlette.middleware import Middleware as StarletteMiddleware  # noqa
-from starlette.responses import Response as StarletteResponse  # noqa
-from starlette.types import ASGIApp  # noqa
+from lilya.middleware import DefineMiddleware
+from lilya.types import ASGIApp
 from typing_extensions import Literal
 
 from esmerald.backgound import BackgroundTask, BackgroundTasks
@@ -24,27 +23,31 @@ from esmerald.routing.gateways import WebSocketGateway
 from esmerald.routing.router import Include
 
 try:
-    from asyncz.schedulers import AsyncIOScheduler  # noqa
+    from asyncz.schedulers import AsyncIOScheduler
 except ImportError:
     AsyncIOScheduler = Any  # type: ignore
 
 try:
-    from esmerald.config.template import TemplateConfig as TemplateConfig  # noqa
+    from esmerald.config.template import TemplateConfig as TemplateConfig
 except MissingDependency:
     TemplateConfig = Any  # type: ignore
 
 if TYPE_CHECKING:
     from esmerald.applications import Esmerald
-    from esmerald.conf.global_settings import EsmeraldAPISettings  # noqa
-    from esmerald.datastructures import Cookie, ResponseHeader, State  # noqa: TC004
-    from esmerald.injector import Inject  # noqa
-    from esmerald.protocols.middleware import MiddlewareProtocol
-    from esmerald.requests import Request  # noqa
-    from esmerald.responses import Response  # noqa
-    from esmerald.routing.apis.base import View  # noqa
-    from esmerald.routing.gateways import Gateway, WebhookGateway  # noqa
-    from esmerald.routing.router import HTTPHandler, Router, WebSocketHandler  # noqa
-    from esmerald.websockets import WebSocket  # noqa
+    from esmerald.conf.global_settings import EsmeraldAPISettings
+    from esmerald.datastructures import Cookie, ResponseHeader, State as State
+    from esmerald.injector import Inject
+    from esmerald.protocols.middleware import MiddlewareProtocol as MiddlewareProtocol
+    from esmerald.requests import Request
+    from esmerald.responses import Response
+    from esmerald.routing.apis.base import View
+    from esmerald.routing.gateways import Gateway, WebhookGateway
+    from esmerald.routing.router import (
+        HTTPHandler as HTTPHandler,
+        Router,
+        WebSocketHandler as WebSocketHandler,
+    )
+    from esmerald.websockets import WebSocket
 else:
     HTTPHandler = Any
     Message = Any
@@ -70,7 +73,7 @@ AsyncAnyCallable = Callable[..., Awaitable[Any]]
 HTTPMethod = Literal["GET", "POST", "DELETE", "PATCH", "PUT", "HEAD"]
 HTTPMethods = get_args(HTTPMethod)
 
-Middleware = StarletteMiddleware
+Middleware = DefineMiddleware
 
 ResponseType = Type[Response]
 
@@ -81,13 +84,7 @@ ExceptionHandler = Callable[[Request, ExceptionType], Response]
 ExceptionHandlerMap = Mapping[Union[int, Type[Exception]], ExceptionHandler]
 
 _ReservedKwargs = Literal[
-    "request",
-    "socket",
-    "headers",
-    "query",
-    "cookies",
-    "state",
-    "data",
+    "request", "socket", "headers", "query", "cookies", "state", "data", "payload"
 ]
 
 ReservedKwargs = get_args(_ReservedKwargs)
